@@ -1,16 +1,14 @@
 package DBIx::Class::Migration::Script;
 
-use Moose;
-use MooseX::Attribute::ENV;
+use Moo;
+use MooX::Attribute::ENV;
 use Pod::Find ();
 use Pod::Usage ();
-use DBIx::Class::Migration::Types qw(
-  LoadableClass ArraySQLTProducers AbsolutePath
-);
+use DBIx::Class::Migration::Types -all;
 use Log::Any;
 use Carp 'croak';
 
-with 'MooseX::Getopt';
+use MooX::Options protect_argv => 0;
 
 sub _log_die {
   my ($self, $msg) = @_;
@@ -30,77 +28,127 @@ use constant {
 };
 
 has log => (
-    is  => 'ro',
-    isa => 'Log::Any::Proxy',
-    default => sub { Log::Any->get_logger( category => 'DBIx::Class::Migration') },
+  is  => 'ro',
+  isa => InstanceOf['Log::Any::Proxy'],
+  default => sub { Log::Any->get_logger( category => 'DBIx::Class::Migration') },
 );
 
-has includes => (
-  traits => ['Getopt'],
+option includes => (
   is => 'ro',
-  isa => 'ArrayRef',
+  isa => ArrayRef,
   predicate => 'has_includes',
-  cmd_aliases => ['include','I', 'lib','libs']);
+  short => join('|', qw(include I lib libs)),
+  format => 's@',
+);
 
-has schema => (is=>'ro', predicate=>'has_schema');
+has schema => (
+  is=>'ro', predicate=>'has_schema',
+);
 
-has schema_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
-  predicate=>'has_schema_class', env_prefix=>ENV_PREFIX, cmd_aliases => 'S');
+option schema_class => (
+  is => 'ro', isa => Str,
+  predicate=>'has_schema_class', env_prefix=>ENV_PREFIX,
+  short => 'S', format => 's',
+);
 
-has target_dir => (traits => [ 'Getopt', 'ENV' ],
-  is => 'ro', isa=> 'Str',
-  predicate=>'has_target_dir', env_prefix=>ENV_PREFIX, cmd_aliases => 'dir');
+option target_dir => (
+  is => 'ro', isa=> Str,
+  predicate=>'has_target_dir', env_prefix=>ENV_PREFIX,
+  short => 'dir', format => 's',
+);
 
-has sandbox_dir => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa=> 'Str',
-  predicate=>'has_sandbox_dir', env_prefix=>ENV_PREFIX);
+option sandbox_dir => (
+  is => 'ro', isa=> Str,
+  predicate=>'has_sandbox_dir', env_prefix=>ENV_PREFIX,
+  format => 's',
+);
 
-has username => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
-  default => '', env_prefix=>ENV_PREFIX, cmd_aliases => 'U');
+option username => (
+  is => 'ro', isa => Str,
+  default => '', env_prefix=>ENV_PREFIX, short => 'U',
+  format => 's',
+);
 
-has password => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
-  default => '', env_prefix=>ENV_PREFIX, cmd_aliases => 'P');
+option password => (
+  is => 'ro', isa => Str,
+  default => '', env_prefix=>ENV_PREFIX, short => 'P',
+  format => 's',
+);
 
-has dsn => (traits => [ 'Getopt', 'ENV' ], is => 'ro',
-  env_prefix=>ENV_PREFIX, isa => 'Str');
+option dsn => (
+  is => 'ro',
+  env_prefix=>ENV_PREFIX, isa => Str,
+  format => 's',
+);
 
-has force_overwrite => (traits => [ 'Getopt' ], is => 'ro', isa => 'Bool',
-  predicate=>'has_force_overwrite', cmd_aliases => 'O');
+option force_overwrite => (
+  is => 'ro', isa => Bool,
+  predicate=>'has_force_overwrite',
+  short => 'O',
+);
 
-has to_version => (traits => [ 'Getopt' ], is => 'ro', isa => 'Int',
-  predicate=>'has_to_version', cmd_aliases => 'V');
+option to_version => (
+  is => 'ro', isa => Int,
+  predicate=>'has_to_version',
+  short => 'V', format => 'i',
+);
 
-has sql_translator_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
+option sql_translator_args => (
+  is => 'ro', isa => HashRef,
   predicate=>'has_sql_translator_args',
-  default => sub { +{ quote_identifiers => 1 }});
+  default => sub { +{ quote_identifiers => 1 }},
+  format => 's%',
+);
 
-has databases => (traits => [ 'Getopt' ], is => 'ro', isa => ArraySQLTProducers,
-  predicate=>'has_databases', cmd_aliases => 'database');
+option databases => (
+  is => 'ro', isa => ArraySQLTProducers,
+  predicate=>'has_databases',
+  short => 'database', format => 's@',
+);
 
-has sandbox_class => (traits => [ 'Getopt', 'ENV' ], is => 'ro', isa => 'Str',
+option sandbox_class => (
+  is => 'ro', isa => Str,
   predicate=>'has_sandbox_class', default=>SANDBOX_SQLITE,
-  cmd_aliases => ['T','sb'], env_prefix=>ENV_PREFIX);
+  env_prefix=>ENV_PREFIX,
+  short => 'T|sb', format => 's',
+);
 
-has dbic_fixture_class => (traits => [ 'Getopt' ], is => 'ro', isa => 'Str',
-  predicate=>'has_dbic_fixture_class');
+option dbic_fixture_class => (
+  is => 'ro', isa => Str,
+  predicate=>'has_dbic_fixture_class',
+  format => 's',
+);
 
-has dbic_fixtures_extra_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_dbic_fixtures_extra_args');
+option dbic_fixtures_extra_args => (
+  is => 'ro', isa => HashRef,
+  predicate=>'has_dbic_fixtures_extra_args',
+  format => 's%',
+);
 
-has dbic_connect_attrs => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_dbic_connect_attrs');
+option dbic_connect_attrs => (
+  is => 'ro', isa => HashRef,
+  predicate=>'has_dbic_connect_attrs',
+  format => 's%',
+);
 
-has dbi_connect_attrs => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_dbi_connect_attrs');
+option dbi_connect_attrs => (
+  is => 'ro', isa => HashRef,
+  predicate=>'has_dbi_connect_attrs',
+  format => 's%',
+);
 
-has extra_schemaloader_args => (traits => [ 'Getopt' ], is => 'ro', isa => 'HashRef',
-  predicate=>'has_extra_schemaloader_args');
+option extra_schemaloader_args => (
+  is => 'ro', isa => HashRef,
+  predicate=>'has_extra_schemaloader_args',
+  format => 's%',
+);
 
-has fixture_sets => (
-  traits => [ 'Getopt' ],
+option fixture_sets => (
   is=>'ro',
-  isa=>'ArrayRef',
+  isa=>ArrayRef,
   default => sub { +['all_tables'] },
-  cmd_aliases => 'fixture_set');
+  short => 'fixture_set', format => 's@',
+);
 
   sub _delegated_commands {
     map { 'cmd_'.$_ => $_ } qw(
@@ -112,18 +160,19 @@ has fixture_sets => (
 
 has migration_class => (
   is => 'ro',
-  traits => [ 'NoGetopt'],
   default => 'DBIx::Class::Migration',
   isa => LoadableClass,
-  coerce => 1);
+);
 
-has migration_sandbox_builder_class => (traits => [ 'Getopt' ],
-  is => 'ro', isa => 'Str', predicate=>'has_migration_sandbox_builder_class');
+option migration_sandbox_builder_class => (
+  is => 'ro', isa => Str, predicate=>'has_migration_sandbox_builder_class',
+  format => 's%',
+);
 
 has migration => (
-  is => 'ro',
-  lazy_build => 1,
-  handles => { _delegated_commands });
+  is => 'lazy',
+  handles => { _delegated_commands },
+);
 
   sub _prepare_schema_args {
     my $self = shift;
@@ -238,7 +287,7 @@ sub _defaults {
 
 sub run {
   my ($self) = @_;
-  my ($argv, @extra_argv) = @{$self->extra_argv};
+  my ($argv, @extra_argv) = @ARGV;
 
   $self->_import_libs(@{$self->includes})
     if $self->has_includes;
@@ -266,6 +315,28 @@ sub new_with_defaults {
   return $class->new_with_options($class->_defaults, @_);
 }
 
+{
+# overrides MooX::Options::Role's one to not exit() on ->new exception
+no warnings 'redefine';
+sub new_with_options {
+  my ($class, %params) = @_;
+  my %cmdline_params = $class->parse_options(%params);
+  if ($cmdline_params{h}) {
+    return $class->options_usage($params{h}, $cmdline_params{h});
+  }
+  if ($cmdline_params{help} ) {
+    return $class->options_help($params{help}, $cmdline_params{help});
+  }
+  if ($cmdline_params{man}) {
+    return $class->options_man($cmdline_params{man});
+  }
+  if ($cmdline_params{usage} ) {
+    return $class->options_short_usage($params{usage}, $cmdline_params{usage});
+  }
+  $class->new(%cmdline_params);
+}
+}
+
 sub run_if_script {
   my $class = shift;
   caller(1) ? $class : $class->run_with_options(@_);
@@ -328,7 +399,7 @@ This is the schema we use as the basic for creating, managing and running your
 deployments.  This should be the full package namespace defining your subclass
 of L<DBIx::Class::Schema>.  For example C<MyApp::Schema>.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_SCHEMA_CLASS
 
 If the L</schema_class> cannot be loaded, a hard exception will be thrown.
@@ -347,7 +418,7 @@ considered a community practice in regards to where to store your distribution
 non code files.  Please see L<File::ShareDir::ProjectDistDir> as well as
 L<File::ShareDir> for more information.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_TARGET_DIR
 
 =head2 sandbox_dir
@@ -366,7 +437,7 @@ Accepts Str.  Not Required
 This should be the username for the database we connect to for deploying
 ddl, ddl changes and fixtures.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_USERNAME
 
 =head2 password
@@ -376,7 +447,7 @@ Accepts Str.  Not Required
 This should be the password for the database we connect to for deploying
 ddl, ddl changes and fixtures.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_PASSWORD
 
 =head2 dsn
@@ -409,7 +480,7 @@ enforce constraints differently it would not be impossible to generate fixtures
 that can be loaded by one database but not another.  Therefore I recommend
 always generated fixtures from a database that is consistent across enviroments.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_DSN
 
 =head2 force_overwrite
@@ -496,7 +567,7 @@ You should review the documenation at L<DBIx::Class::Migration::MySQLSandbox> or
 L<DBIx::Class::Migration::PostgresqlSandbox> because those delegates also build
 some helper scripts, intended to help you use a sandbox.
 
-Uses L<MooseX::Attribute::ENV> to let you populate values from %ENV.  Uses key
+Uses L<MooX::Attribute::ENV> to let you populate values from %ENV.  Uses key
 DBIC_MIGRATION_SANDBOX_CLASS
 
 If you need to create your own custom database sandboxes, please see:
@@ -574,7 +645,7 @@ for creating temporary sandboxes when you want to test your migrations.
 
     dbic-migration -Ilib install
 
-Since this class consumes the L<MooseX::GetOpt> role, it can be run directly
+Since this class uses L<MooX::Options>, it can be run directly
 as a commandline application.  The following is a list of commands we support
 as well as the options / flags associated with each command.
 
@@ -781,7 +852,7 @@ script wrapper).
 =head2 run_with_options
 
 Given a Hash of initial arguments, merges those with the results of values passed
-on the commandline (via L<MooseX::Getopt>) and run.
+on the commandline (via L<MooX::Options>) and run.
 
 =head2 run
 
